<?php

namespace Btravel\Partners\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Partners\Models\Partner;

class PartnerPolicy
{

    /**
     * Determine if the given user can view the partner.
     *
     * @param UserPolicy $user
     * @param Partner $partner
     *
     * @return bool
     */
    public function view(UserPolicy $user, Partner $partner)
    {
        if ($user->canDo('partners.partner.view') && $user->isAdmin()) {
            return true;
        }

        return $partner->user_id == user_id() && $partner->user_type == user_type();
    }

    /**
     * Determine if the given user can create a partner.
     *
     * @param UserPolicy $user
     * @param Partner $partner
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('partners.partner.create');
    }

    /**
     * Determine if the given user can update the given partner.
     *
     * @param UserPolicy $user
     * @param Partner $partner
     *
     * @return bool
     */
    public function update(UserPolicy $user, Partner $partner)
    {
        if ($user->canDo('partners.partner.edit') && $user->isAdmin()) {
            return true;
        }

        return $partner->user_id == user_id() && $partner->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given partner.
     *
     * @param UserPolicy $user
     * @param Partner $partner
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Partner $partner)
    {
        return $partner->user_id == user_id() && $partner->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given partner.
     *
     * @param UserPolicy $user
     * @param Partner $partner
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Partner $partner)
    {
        if ($user->canDo('partners.partner.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given partner.
     *
     * @param UserPolicy $user
     * @param Partner $partner
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Partner $partner)
    {
        if ($user->canDo('partners.partner.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
